PCB Environment: Net Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
Net Class Reference

## Public Member Functions
| Net (const std::string &name)
Net * | clone (CloneEnv &) const
PCBoard * | getBoard () const
| Board-wide unique name and ID.
std::string | name () const
uint | id () const
const Color & | getColor () const
const std::set< Pin * > & | getPins () const
uint | numPins () const
bool | contains (const Pin *T) const
bool | empty () const
uint | numConnections () const
const std::vector< Connection * > & | connections () const
Connection * | connection (uint i) const
Connection * | getConnectionBetween (const Pin &, const Pin &) const
uint | validateTrack (const Track &) const
Real | getMinTrackWidth () const
Real | getMinClearance () const
bool | hasViaExtent () const
| FIXME: via extent is not handled in A*.
uint | getViaStartLayer () const
uint | getViaHeight () const
Real | getViaDiameter () const
bool | buriedViasOK () const
uint32_t | getLayerMask () const
bool | isGroundOrPower () const
bool | isGround () const
SignalType | signalType () const
void | insert (Pin &)
void | remove (Pin &)
Connection * | addConnection (Pin *sourcePin, const Point_25 &source, Pin *targetPin, const Point_25 &target)
void | autocreateConnections ()
| Create 2-pin connections from the set of pins.
void | sortConnections ()
void | setMinTrackWidth (Real)
void | setMinClearance (Real c)
void | setViaExtent (uint start, uint h)
void | setViaDiameter (Real d)
void | setLayerMask (uint32_t m)
void | setLayerMaskFromSignalType ()
void | setSignalType (SignalType t)
void | setBoard (PCBoard *board)
void | setId (uint id)
| NOTE: connection ID = (net ID << 16) | connection index, so net ID must be < 0x7fff.
void | setColor (const Color &c)
void | setColorAuto (bool singleColorPerType=false)
| Colorize according to signal type and net number/id.
bool | extract (Component &)
| Remove all connections connected to @Component and return whether the net is then empty.
bool | pruneConnections (std::set< Connection * > &keep)
| Remove all connections not in @keep and return whether the net is then empty.
std::string | str () const
PyObject * | getConnectionsPy (uint depth, bool asNumpy) const
PyObject * | getPinsPy () const
PyObject * | getPy (uint depth, bool asNumpy) const

## Static Public Member Functions
static SignalType | getLikelySignalTypeForName (const std::string &)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Net.hpp